@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2023 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -177,9 +177,7 @@ if ($config['poller_id'] == 1 || read_config_option('storage_location')) {
 		$graph_data_array['effective_user'] = $_SESSION['sess_user_id'];
 	}
 
-	$hostname = db_fetch_cell('SELECT hostname FROM poller WHERE id = 1');
-
-	$url  = get_url_type() . '://' . $hostname . $config['url_path'] . 'remote_agent.php?action=graph_json';
+	$url  = $config['url_path'] . 'remote_agent.php?action=graph_json';
 	$url .= '&local_graph_id=' . get_request_var('local_graph_id');
 	$url .= '&rra_id=' . $rra_id;
 
@@ -187,9 +185,7 @@ if ($config['poller_id'] == 1 || read_config_option('storage_location')) {
 		$url .= '&' . $variable . '=' . $value;
 	}
 
-	$fgc_contextoption = get_default_contextoption();
-	$fgc_context       = stream_context_create($fgc_contextoption);
-	$output            = @file_get_contents($url, false, $fgc_context);
+	$output = call_remote_data_collector(1, $url);
 }
 
 $output = trim($output);
