@@ -22,21 +22,54 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_2_11() {
-	db_install_execute("CREATE TABLE IF NOT EXISTS `processes` (
-		`id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
-		`pid` int(10) unsigned NOT NULL DEFAULT 0,
-		`tasktype` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
-		`taskname` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
-		`taskid` int(10) unsigned NOT NULL DEFAULT 0,
-		`timeout` int(11) DEFAULT 300,
-		`started` timestamp NOT NULL DEFAULT current_timestamp(),
-		`last_update` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00',
-		PRIMARY KEY (`pid`,`tasktype`,`taskname`,`taskid`),
-		KEY `tasktype` (`tasktype`),
-		KEY `pid` (`pid`),
-		KEY `id` (`id`))
-		ENGINE=MEMORY
-		COMMENT='Stores Process Status for Cacti Background Processes'");
+function upgrade_to_1_2_26() {
+	db_install_execute("ALTER TABLE `settings` MODIFY `value` varchar(4096) not null default ''");
+	db_install_execute("ALTER TABLE `settings_user` MODIFY `value` varchar(4096) not null default ''");
+
+	/* rerun this function just in case for some reason it was missed */
+	$duplicates = db_install_fetch_assoc('SELECT hex, COUNT(*) AS totals
+		FROM colors
+		GROUP BY hex
+		HAVING totals > 1');
+
+	if (cacti_sizeof($duplicates['data'])) {
+		$duplicates = $duplicates['data'];
+
+		foreach($duplicates as $duplicate) {
+			$hexes_results = db_install_fetch_assoc('SELECT id, hex
+				FROM colors
+				WHERE hex = ?
+				ORDER BY id ASC',
+				array($duplicate['hex']), true);
+			$hexes = $hexes_results['data'];
+
+			$first = true;
+
+			foreach($hexes as $hex) {
+				if ($first) {
+					$keephex = $hex['id'];
+					$first   = false;
+				} else {
+					db_install_execute('UPDATE graph_templates_item
+						SET color_id = ?
+						WHERE color_id = ?',
+						array($keephex, $hex['id']));
+
+					if (db_table_exists('color_template_items')) {
+						db_install_execute('UPDATE color_template_items
+							SET color_id = ?
+							WHERE color_id = ?',
+							array($keephex, $hex['id']));
+					}
+
+					db_install_execute('DELETE FROM colors WHERE id = ?', array($hex['id']));
+				}
+			}
+		}
+
+		if (!db_index_exists('colors', 'hex')) {
+			db_install_add_key('colors', 'UNIQUE INDEX', 'hex', array('hex'));
+		}
+	}
 }
 
