@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2023 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -1463,10 +1463,10 @@ function reports_edit() {
 	reports_tabs(get_request_var('id'));
 
 	if (isset($report['id'])) {
-		$report['mailtime'] = date(reports_date_time_format(), $report['mailtime']);
+		$report['mailtime'] = date('Y-m-d H:i', strtotime(date('Y-m-d H:i:00', $report['mailtime'])));
 		$header_label = __('[edit: %s]', $report['name']);
 	} else {
-		$report['mailtime'] = date(reports_date_time_format(), floor(time() / read_config_option('poller_interval')) * read_config_option('poller_interval'));
+		$report['mailtime'] = date('Y-m-d H:i', strtotime(date('Y-m-d H:i:00', floor(time() / read_config_option('poller_interval')) * read_config_option('poller_interval'))));
 		$header_label = __('[new]');
 	}
 
@@ -1509,6 +1509,7 @@ function reports_edit() {
 			$('#mailtime').datetimepicker({
 				minuteGrid: 10,
 				stepMinute: 1,
+				showSecond: false,
 				showAnim: 'slideDown',
 				numberOfMonths: 1,
 				timeFormat: 'HH:mm',
