@@ -779,9 +779,19 @@ function api_plugin_uninstall_integrated() {
 	}
 }
 
+function api_plugin_hooks_found($plugin) {
+	return db_fetch_cell_prepared('SELECT COUNT(*) FROM plugin_hooks WHERE name = ?', array($plugin)) ? true:false;
+}
+
+function api_plugin_realms_found($plugin) {
+	return db_fetch_cell_prepared('SELECT COUNT(*) FROM plugin_realms WHERE plugin = ?', array($plugin)) ? true:false;
+}
+
 function api_plugin_uninstall($plugin, $tables = true) {
 	global $config;
 
+	$plugin_found = false;
+
 	if (file_exists($config['base_path'] . "/plugins/$plugin/setup.php")) {
 		include_once($config['base_path'] . "/plugins/$plugin/setup.php");
 
@@ -790,11 +800,18 @@ function api_plugin_uninstall($plugin, $tables = true) {
 
 		if (function_exists($function)) {
 			$function();
+
+			$plugin_found = true;
 		}
 	}
 
-	api_plugin_remove_hooks($plugin);
-	api_plugin_remove_realms($plugin);
+	if (api_plugin_hooks_found($plugin)) {
+		api_plugin_remove_hooks($plugin);
+	}
+
+	if (api_plugin_realms_found($plugin)) {
+		api_plugin_remove_realms($plugin);
+	}
 
 	db_execute_prepared('DELETE FROM plugin_config
 		WHERE directory = ?',
@@ -808,7 +825,9 @@ function api_plugin_uninstall($plugin, $tables = true) {
 			array($plugin));
 	}
 
-	api_plugin_replicate_config();
+	if ($plugin_found) {
+		api_plugin_replicate_config();
+	}
 }
 
 function api_plugin_check_config($plugin) {
