@@ -72,7 +72,13 @@ if (!cacti_sizeof($page)) {
 		}
 
 		if (preg_match('/^((((ht|f)tp(s?))\:\/\/){1}\S+)/i', $page['contentfile'])) {
-			print '<iframe id="content" src="' . $page['contentfile'] . '" sandbox="allow-scripts allow-popups allow-forms" frameborder="0"></iframe>';
+			if (filter_var($page['contentfile'], FILTER_VALIDATE_URL)) {
+				print '<iframe id="content" src="' . html_escape($page['contentfile']) . '" sandbox="allow-scripts allow-popups allow-forms" frameborder="0"></iframe>';
+			} else {
+				$message = __esc("External Link ID '%s' with Title '%s' attempted to inject an invalid URL and was blocked!", $page['id'], $page['title']);
+				cacti_log($message, false, 'SECURITY');
+				raise_message('invalid_url', $message, MESSAGE_LEVEL_ERROR);
+			}
 		} else {
 			print '<div id="content">';
 
@@ -80,7 +86,7 @@ if (!cacti_sizeof($page)) {
 			$file     = realpath($basepath . '/' . $page['contentfile']);
 
 			if ($file !== false && substr($file, 0, strlen($basepath)) == $basepath) {
-				print file_get_contents($file);
+				include_once($file);
 			} else {
 				print '<h1>The file \'' . html_escape($page['contentfile']) . '\' does not exist!!</h1>';
 			}
