@@ -719,7 +719,7 @@ function format_plugin_row($plugin, $last_plugin, $include_ordering, $table) {
 	}
 
 	if ($config['poller_id'] > 1) {
-		if (strpos($plugin['capabilities'], 'remote_collect:1') !== false || strpos($plugin['capabilities'], 'remote_poller:1') !== false) {
+		if (isset($plugin['capabilities']) && (strpos($plugin['capabilities'], 'remote_collect:1') !== false || strpos($plugin['capabilities'], 'remote_poller:1') !== false)) {
 			if ($plugin['remote_status'] == '-1') {
 				$status = plugin_is_compatible($plugin['directory']);
 				$row .= ' / ' . __('Not Compatible, %s', $status['requires']);
@@ -866,7 +866,7 @@ function plugin_actions($plugin, $table) {
 	}
 
 	if ($config['poller_id'] > 1) {
-		if (strpos($plugin['capabilities'], 'remote_collect:1') !== false || strpos($plugin['capabilities'], 'remote_poller:1') !== false) {
+		if (isset($plugins['capabilities']) && (strpos($plugin['capabilities'], 'remote_collect:1') !== false || strpos($plugin['capabilities'], 'remote_poller:1') !== false)) {
 			if ($plugin['remote_status'] == 1) { // Installed and Active
 				// TO-DO: Disabling here does not make much sense as the main will be replicated
 				// with any change of any other plugin thus undoing.  Fix that moving forward
