@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2023 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -47,7 +47,7 @@ switch (get_request_var('action')) {
 
 		break;
 	case 'send':
-		get_request_var('id');
+		get_filter_request_var('id');
 
 		reports_send(get_request_var('id'));
 
@@ -56,7 +56,7 @@ switch (get_request_var('action')) {
 	case 'ajax_dnd':
 		reports_item_dnd();
 
-		header('Location: reports_admin.php?action=edit&tab=items&id=' . get_request_var('id'));
+		header('Location: reports_admin.php?action=edit&tab=items&id=' . get_filter_request_var('id'));
 		break;
 	case 'setvar':
 		$changed = reports_item_validate();
@@ -129,21 +129,21 @@ switch (get_request_var('action')) {
 		reports_form_actions();
 		break;
 	case 'item_movedown':
-		get_request_var('id');
+		get_filter_request_var('id');
 
 		reports_item_movedown();
 
 		header('Location: reports_user.php?action=edit&tab=items&id=' . get_request_var('id'));
 		break;
 	case 'item_moveup':
-		get_request_var('id');
+		get_filter_request_var('id');
 
 		reports_item_moveup();
 
 		header('Location: reports_user.php?action=edit&tab=items&id=' . get_request_var('id'));
 		break;
 	case 'item_remove':
-		get_request_var('id');
+		get_filter_request_var('id');
 
 		reports_item_remove();
 
