@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2024 The Cacti Group                                 |
+ | Copyright (C) 2004-2023 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -223,8 +223,8 @@ function ss_net_snmp_disk_bytes($host_id_or_hostname = '') {
 			}
 		}
 
-		$data = "'" . json_encode($current) . "'";
-		shell_exec("echo $data > $tmpdir/$tmpfile");
+		$data = json_encode($current);
+		file_put_contents("$tmpdir/$tmpfile", $data);
 	}
 
 	if ($found) {
